package cmd

import (
	"errors"
	"fmt"
	"os/exec"
	"strings"
)

func Pip(args ...string) (output string, err error) {

	if _, err := Which("python3"); err != nil {
		if errors.Is(err, ErrNotFound) {
			return "", PythonNotFound
		} else {
			return "", err
		}
	}

	command := exec.Command("python3", "-m", "pip")
	command.Args = append(command.Args, args...)

	outputBytes, err := command.Output()
	if err != nil {
		var exitErr *exec.ExitError
		if errors.As(err, &exitErr) {
			return "", fmt.Errorf("command error: %w", err)
		}
	}

	return strings.Trim(string(outputBytes), "\n"), nil

}
